@@ -174,6 +174,10 @@ class Page(Container):
 
     def extract_table(self, table_settings={}):
         tables = self.find_tables(table_settings)
+        
+        if len(tables) == 0:
+            return None
+
         # Return the largest table, as measured by number of cells.
         sorter = lambda x: (-len(x.cells), x.bbox[1], x.bbox[0])
         largest = list(sorted(tables, key=sorter))[0]
